@@ -23,8 +23,8 @@
  *
  */
 
-#ifndef _EXTRACTINT_H
-#define _EXTRACTINT_H
+#ifndef _MAGIC__EXTRACT__EXTRACTINT_H
+#define _MAGIC__EXTRACT__EXTRACTINT_H
 
 #include "database/database.h"
 
@@ -506,7 +506,6 @@ typedef struct extDevice
 	 */
 
     HashTable		 exts_deviceResist;
-    ResValue		 exts_linearResist;
 
 	/*
 	 * Mask of the types of tiles that connect to the channel terminals
@@ -1118,4 +1117,4 @@ extern int  extMakeUnique();
 
 #include "extDebugInt.h"
 
-#endif /* _EXTRACTINT_H */
+#endif /* _MAGIC__EXTRACT__EXTRACTINT_H */
