@@ -71,7 +71,7 @@ global int **GrStippleTable = NULL;
 global int grNumStipples = 0;
 
 /* MUST be the same indices as the constants in graphicsInt.h */
-char *fillStyles[] = {
+const char * const fillStyles[] = {
 	"solid",
 	"cross",
 	"outline",
@@ -229,8 +229,16 @@ styleBuildDisplayStyle(line, version)
 					 */
 
 	/* Allow colors to be specified by index or by name */
-	if (sscanf(colorName, ((version > 6) ? "%i" : "%o"), &color) <= 0)
-	    color = GrNameToColor(colorName);
+	if (version > 6)
+	{
+	    if (sscanf(colorName, "%i", &color) <= 0)
+		color = GrNameToColor(colorName);
+	}
+	else
+	{
+	    if (sscanf(colorName, "%o", (unsigned int *)&color) <= 0)
+		color = GrNameToColor(colorName);
+	}
 
 	newstyle->style.mask = (mask & grBitPlaneMask);
 	newstyle->style.color = (color & grBitPlaneMask);
@@ -408,7 +416,7 @@ char *libPath;
 {
     FILE *inp;
     int res = 0;
-    int i, scount, processed = DISP_VERSION;
+    int i, scount = 0, processed = DISP_VERSION;
     char fullName[256];
     dstylelink *sstyle;
     int MaxTechStyles = 0, MaxTileStyles = 0;
@@ -542,9 +550,9 @@ char *libPath;
 	    }
 	    else
 	    {
-		int newres = TRUE;
-
+		int newres;
 recovery:
+		newres = TRUE;
 		switch (section)
 		{
 		    case LAYOUT_STYLES:
